maranet.cli package
===================

Subpackages
-----------

.. toctree::

    maranet.cli.client

Submodules
----------

maranet.cli.server module
-------------------------

.. automodule:: maranet.cli.server
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: maranet.cli
    :members:
    :undoc-members:
    :show-inheritance:
